; The CMD file.
;
; Two parts: 1. Command definition and  2. State entry
; (state entry is after the commands def section)
;
; 1. Command definition
; ---------------------
; Note: The commands are CASE-SENSITIVE, and so are the command names.
; The eight directions are:
;   B, DB, D, DF, F, UF, U, UB     (all CAPS)
;   corresponding to back, down-back, down, downforward, etc.
; The six buttons are:
;   a, b, c, x, y, z               (all lower case)
;   In default key config, abc are are the bottom, and xyz are on the
;   top row. For 2 button characters, we recommend you use a and b.
;   For 6 button characters, use abc for kicks and xyz for punches.
;
; Each [Command] section defines a command that you can use for
; state entry, as well as in the CNS file.
; The command section should look like:
;
;   [Command]
;   name = "some_name"
;   command = the_command
;   time = time (optional -- defaults to 15 if omitted)
;
; - some_name
;   A name to give that command. You'll use this name to refer to
;   that command in the state entry, as well as the CNS. It is case-
;   sensitive (QCB_a is NOT the same as Qcb_a or QCB_A).
;
; - command
;   list of buttons or directions, separated by commas.
;   Directions and buttons can be preceded by special characters:
;   slash (/) - means the key must be held down
;          egs. command = /D       ;hold the down direction
;               command = /F, a    ;hold fwd while you press a
;   tilde (~) - to detect key releases
;          egs. command = ~a       ;release the a button
;               command = ~D, F, a ;release down, press fwd, then a
;          If you want to detect "charge moves", you can specify
;          the time the key must be held down for (in game-ticks)
;          egs. command = ~30a     ;hold a for at least 30 ticks, then release
;               command = ~30
;   dollar ($) - Direction-only: detect as 4-way
;          egs. command = $D       ;will detect if D, DB or DF is held
;               command = $B       ;will detect if B, DB or UB is held
;   plus (+) - Buttons only: simultaneous press
;          egs. command = a+b      ;press a and b at the same time
;               command = x+y+z    ;press x, y and z at the same time
;   You can combine them:
;     eg. command = ~30$D, a+b     ;hold D, DB or DF for 30 ticks, release,
;                                  ;then press a and b together
;   It's recommended that for most "motion" commads, eg. quarter-circle-fwd,
;   you start off with a "release direction". This matches the way most
;   popular fighting games implement their engine.
;
; - time (optional)
;   Time allowed to do the command, given in game-ticks. Defaults to 15
;   if omitted
;
; If you have two or more commands with the same name, all of them will
; work. You can use it to allow multiple motions for the same move.
;
; Some common commands are given below. Delete, add, or modify as you wish.

;-| Super Motions |--------------------------------------------------------
[Command]
name = "cocoon_x"
command = ~D,DF,F,x+z

[Command]
name = "cocoon_y"
command = ~D,DF,F,y+x

[Command]
name = "cocoon_z"
command = ~D,DF,F,z+y

;-| Special Motions |------------------------------------------------------
;-----------------
[Command]
name = "webthrow_x"
command = ~D,DF,F, x

[Command]
name = "webthrow_y"
command = ~D,DF,F, y

[Command]
name = "webthrow_z"
command = ~D,DF,F, z

;-| Double Tap |-----------------------------------------------------------
[Command]
name = "FF";Required (do not remove)
command = F, F
time = 15

[Command]
name = "BB";Required (do not remove)
command = B, B
time = 15

;-| 2/3 Button Combination |-----------------------------------------------
[Command]
name = "recovery";Required (do not remove)
command = a+b
time = 1

[Command]
name = "ab"
command = a+b
time = 1

[Command]
name = "bc"
command = b+c
time = 1

[Command]
name = "ca"
command = c+a
time = 1

[Command]
name = "xy"
command = x+y
time = 1

[Command]
name = "zx"
command = z+x
time = 1

[Command]
name = "yz"
command = y+z
time = 1

;-| Dir + Button |---------------------------------------------------------
[Command]
name = "fwd_a"
command = /F,a
time = 1

[Command]
name = "fwd_b"
command = /F,b
time = 1

[Command]
name = "fwd_c"
command = /F,c
time = 1

[Command]
name = "fwd_x"
command = /F,x
time = 1

[Command]
name = "fwd_y"
command = /F,y
time = 1

[Command]
name = "fwd_z"
command = /F,z
time = 1

[Command]
name = "back_a"
command = /B,a
time = 1

[Command]
name = "back_b"
command = /B,b
time = 1

[Command]
name = "back_c"
command = /B,c
time = 1

[Command]
name = "back_y"
command = /B,y
time = 1

[Command]
name = "back_z"
command = /B,z
time = 1

[Command]
name = "down_a"
command = /$D,a
time = 1

[Command]
name = "down_b"
command = /$D,b
time = 1

[Command]
name = "down_c"
command = /$D,c
time = 1

[Command]
name = "fwd_ab"
command = /F, a+b
time = 1

[Command]
name = "back_ab"
command = /B, a+b
time = 1

;-| Single Button |---------------------------------------------------------
[Command]
name = "a"
command = a
time = 1

[Command]
name = "b"
command = b
time = 1

[Command]
name = "c"
command = c
time = 1

[Command]
name = "x"
command = x
time = 1

[Command]
name = "y"
command = y
time = 1

[Command]
name = "z"
command = z
time = 1

[Command]
name = "start"
command = s
time = 1

;-| Hold Button |---------------------------------------------------------
[Command]
name = "hold_a"
command = /a
time = 1

[Command]
name = "hold_b"
command = /b
time = 1

[Command]
name = "hold_c"
command = /c
time = 1

[Command]
name = "hold_x"
command = /x
time = 1

[Command]
name = "hold_y"
command = /y
time = 1

[Command]
name = "hold_z"
command = /z
time = 1

;-| Hold Dir |--------------------------------------------------------------
[Command]
name = "holdfwd";Required (do not remove)
command = /$F
time = 1

[Command]
name = "holdback";Required (do not remove)
command = /$B
time = 1

[Command]
name = "holdup";Required (do not remove)
command = /$U
time = 1

[Command]
name = "holddown";Required (do not remove)
command = /$D
time = 1

[Command]
name = "holddf"
command = /$D, /$F
time = 1

;---------------------------------------------------------------------------
; 2. State entry
; --------------
; This is where you define what commands bring you to what states.
;
; Each state entry block looks like:
;   [State -1]                  ;Don't change this
;   type = ChangeState          ;Don't change this
;   value = new_state_number
;   trigger1 = command = "command_name"
;   . . .  (any additional triggers)
;
; - new_state_number is the number of the state to change to
; - command_name is the name of the command (from the section above)
; - Useful triggers to know:
;   - statetype
;       S, C or A : current state-type of player (stand, crouch, air)
;   - ctrl
;       0 or 1 : 1 if player has control. Unless "interrupting" another
;                move, you'll want ctrl = 1
;   - stateno
;       number of state player is in - useful for "move interrupts"
;   - movecontact
;       0 or 1 : 1 if player's last attack touched the opponent
;                useful for "move interrupts"
;
; For reference on triggers, see CNS documentation.
;
; Just for your information (skip if you're not interested):
; This part is an extension of the CNS. "State -1" is a special state
; that is executed once every game-tick, regardless of what other state
; you are in. 


; Don't remove the following line. It's required by the CMD standard.
[Statedef -1]

;===========================================================================

;------------------
; CrouchForward
;[State -1]
;type = changeState
;value = 13
;trigger1 = command = "holdfwd"
;trigger1 = statetype = C
;trigger1 = ctrl = 1
;---------------------------------------------------------------------------
;RunFwd
[State -1]
type = ChangeState
value = 100
trigger1 = command = "FF"
trigger1 = statetype = S
trigger1 = ctrl = 1

;---------------------------------------------------------------------------
;RunBack
[State -1]
type = ChangeState
value = 105
trigger1 = command = "BB"
trigger1 = statetype = S
trigger1 = ctrl = 1

;---------------------------------------------------------------------------
;Stand_Throw (close dir+b)
[State -1]
type = ChangeState
value = 900
triggerall = statetype = S
triggerall = ctrl = 1
triggerall = p2bodydist X <= 10 ;Near P2
trigger1 = command = "fwd_z";p2 stand
trigger1 = stateno != 100    ;Not running
trigger1 = p2movetype != H
trigger2 = command = "fwd_z";p2 crouch
trigger2 = stateno != 100    ;Not running
trigger2 = p2statetype = C
trigger2 = p2movetype != H
trigger3 = command = "back_z";p2 stand
trigger3 = p2statetype = S
trigger3 = p2movetype != H
trigger4 = command = "back_z";p2 crouch
trigger4 = p2statetype = C
trigger4 = p2movetype != H

;---------------------------------------------------------------------------
;Air_Throw1 (close dir+b)
; This is disabled right now. Remove the "null;" below when you
; want to use it.
[State -1]
type = ChangeState
value = 950
triggerall = statetype = A
triggerall = ctrl = 1
triggerall = p2bodydist X < 9
triggerall = p2bodydist Y > -22
triggerall = p2bodydist Y < 22
triggerall = p2statetype = A
triggerall = p2movetype != H
trigger1 = command = "fwd_b"
trigger2 = command = "back_b"


;===========================================================================
;--------------------------------------------------------
; cocoon_x
[State -1]
type = ChangeState
value = 1700
triggerall = numproj = 0
triggerall = command = "cocoon_x"
triggerall = power >= 1000 ; Level 1.0 Super
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = statetype != A
trigger2 = ctrl = 1
trigger3 = StateType != A
trigger3 = hitdefattr = SC, NA, SA
trigger4 = stateno = 230
trigger4 = movecontact = 1
trigger5 = stateno = 240
trigger5 = movecontact = 1
trigger6 = stateno = 250
trigger6 = movecontact = 1
trigger7 = stateno = 200
trigger7 = movecontact = 1
trigger8 = stateno = 210
trigger8 = movecontact = 1
trigger9 = stateno = 220
trigger9 = movecontact = 1
trigger10 = stateno = 3000
trigger10 = movecontact = 1
trigger11 = stateno = 1000
trigger11 = p2bodydist X < 5
trigger11 = movecontact = 1
trigger12 = stateno = 1001
trigger12 = p2bodydist X < 5
trigger12 = movecontact = 1
trigger13 = stateno = 1002
trigger13 = p2bodydist X < 5
trigger13 = movecontact = 1

; cocoon_y
[State -1]
type = ChangeState
value = 1701
triggerall = numproj = 0
triggerall = command = "cocoon_y"
triggerall = power >= 2000 ; Level 2.0 Super
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = statetype != A
trigger2 = ctrl = 1
trigger3 = StateType != A
trigger3 = hitdefattr = SC, NA, SA
trigger4 = stateno = 230
trigger4 = movecontact = 1
trigger5 = stateno = 240
trigger5 = movecontact = 1
trigger6 = stateno = 250
trigger6 = movecontact = 1
trigger7 = stateno = 200
trigger7 = movecontact = 1
trigger8 = stateno = 210
trigger8 = movecontact = 1
trigger9 = stateno = 220
trigger9 = movecontact = 1
trigger10 = stateno = 3000
trigger10 = movecontact = 1
trigger11 = stateno = 1000
trigger11 = p2bodydist X < 5
trigger11 = movecontact = 1
trigger12 = stateno = 1001
trigger12 = p2bodydist X < 5
trigger12 = movecontact = 1
trigger13 = stateno = 1002
trigger13 = p2bodydist X < 5
trigger13 = movecontact = 1

; cocoon_z
[State -1]
type = ChangeState
value = 1702
triggerall = numproj = 0
triggerall = command = "cocoon_z"
triggerall = power >= 3000 ; Level 3.0 Super
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = statetype != A
trigger2 = ctrl = 1
trigger3 = StateType != A
trigger3 = hitdefattr = SC, NA, SA
trigger4 = stateno = 230
trigger4 = movecontact = 1
trigger5 = stateno = 240
trigger5 = movecontact = 1
trigger6 = stateno = 250
trigger6 = movecontact = 1
trigger7 = stateno = 200
trigger7 = movecontact = 1
trigger8 = stateno = 210
trigger8 = movecontact = 1
trigger9 = stateno = 220
trigger9 = movecontact = 1
trigger10 = stateno = 3000
trigger10 = movecontact = 1
trigger11 = stateno = 1000
trigger11 = p2bodydist X < 5
trigger11 = movecontact = 1
trigger12 = stateno = 1001
trigger12 = p2bodydist X < 5
trigger12 = movecontact = 1
trigger13 = stateno = 1002
trigger13 = p2bodydist X < 5
trigger13 = movecontact = 1

;Air cocoon_x
[State -1]
type = ChangeState
value = 1703
triggerall = numproj = 0
triggerall = command = "cocoon_x"
triggerall = power >= 1000 ; Level 1.0 Super
trigger1 = statetype = A
trigger1 = ctrl = 1
trigger2 = stateno = 630 ;air_x
trigger2 = movecontact = 1

;Air cocoon_y
[State -1]
type = ChangeState
value = 1704
triggerall = numproj = 0
triggerall = command = "cocoon_y"
triggerall = power >= 2000 ; Level 2.0 Super
trigger1 = statetype = A
trigger1 = ctrl = 1
trigger2 = stateno = 640 ;air_y
trigger2 = movecontact = 1

;Air cocoon_z
[State -1]
type = ChangeState
value = 1705
triggerall = numproj = 0
triggerall = command = "cocoon_z"
triggerall = power >= 3000 ; Level 3.0 Super
trigger1 = statetype = A
trigger1 = ctrl = 1
trigger2 = stateno = 650 ;air_z
trigger2 = movecontact = 1
;------------------------------------------------------------------------
; Web Ball Weak
[State -1]
type = ChangeState
value = 1000
triggerall = numproj = 0
triggerall = command = "webthrow_x"
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = stateno = 230 ;stand_x
trigger2 = movecontact = 1
trigger3 = stateno = 430 ;crouching_x
trigger3 = statetime <= 2

; Web Ball Strong
[State -1]
type = ChangeState
value = 1001
triggerall = numproj = 0
triggerall = command = "webthrow_y"
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = stateno = 240 ;stand_y
trigger2 = movecontact = 1
trigger3 = stateno = 440 ;crouching_y
trigger3 = statetime <= 2

; Web Ball Fierce
[State -1]
type = ChangeState
value = 1002
triggerall = numproj = 0
triggerall = command = "webthrow_z"
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = stateno = 250 ;stand_z
trigger2 = movecontact = 1
trigger3 = stateno = 450 ;crouching_z
trigger3 = statetime <= 2

; Web Ball Air Weak
[State -1]
type = ChangeState
value = 1003
triggerall = numproj = 0
triggerall = command = "webthrow_x"
trigger1 = statetype = A
trigger1 = ctrl = 1
trigger2 = stateno = 630 ;air_x
trigger2 = movecontact = 1

; Web Ball Air strong
[State -1]
type = ChangeState
value = 1004
triggerall = numproj = 0
triggerall = command = "webthrow_y"
trigger1 = statetype = A
trigger1 = ctrl = 1
trigger2 = stateno = 640 ;air_y
trigger2 = movecontact = 1

; Web Ball Air Fierce
[State -1]
type = ChangeState
value = 1005
triggerall = numproj = 0
triggerall = command = "webthrow_z"
trigger1 = statetype = A
trigger1 = ctrl = 1
trigger2 = stateno = 650 ;air_z
trigger2 = movecontact = 1
;---------------------------------------------------------------------------
;Stand_A
[State -1]
type = ChangeState
value = 200
triggerall = command = "a";Place name of command here
triggerall = command != "holddown";Standing moves should have this line
 ;The following is true if Player is in stand state, and has control
trigger1 = statetype = S
trigger1 = ctrl = 1
 ;Uncomment the following if you want to be able to do a Stand_A rapidly
trigger2 = stateno = 440
trigger2 = movecontact = 1 
trigger4 = P2Dist X <= 30
trigger3 = stateno = 230
trigger3 = movecontact = 1 
trigger4 = stateno = 450
trigger4 = movecontact = 1 

;---------------------------------------------------------------------------
;Stand_B
[State -1]
type = ChangeState
value = 210
triggerall = command = "b"
triggerall = command != "holddown"
trigger1 = statetype = S
trigger1 = ctrl = 1
 ;Uncomment the following if you want to be able to "chain" the attack
 ;from a Stand_A (state 200)
trigger2 = stateno = 200
trigger2 = movecontact = 1  ;If move hits, or is guarded by opponent
trigger3 = stateno = 230
trigger3 = movecontact = 1 
trigger6 = P2Dist X <= 30
trigger4 = stateno = 240
trigger4 = movecontact = 1 
trigger5 = stateno = 250
trigger5 = movecontact = 1 
trigger6 = stateno = 450
trigger6 = movecontact = 1

;--------------
;Stand_C
[State -1]
type = ChangeState
value = 220
triggerall = command = "c"
triggerall = command != "holddown"
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger3 = P2Dist X <= 30
trigger2 = stateno = 210
trigger2 = movecontact = 1
trigger3 = stateno = 450
trigger3 = movecontact = 1

;------------------
; Stand_X
[State -1]
type = ChangeState
value = 230
triggerall = command = "x"
triggerall = command != "holddown"
trigger1 = statetype = s
trigger1 = ctrl = 1
trigger3 = P2Dist X <= 30
trigger2 = stateno = 440
trigger2 = movecontact = 1 
trigger3 = stateno = 450
trigger3 = movecontact = 1 

;-------------------
; Stand_Y
[State -1]
type = ChangeState
value = 240
triggerall = command = "y"
triggerall = command != "holddown"
trigger1 = statetype = s
trigger1 = ctrl = 1
trigger6 = P2Dist X <= 30
trigger2 = stateno = 230
trigger2 = movecontact = 1 
trigger3 = stateno = 200
trigger3 = movecontact = 1 
trigger4 = stateno = 210
trigger4 = movecontact = 1
trigger5 = stateno = 440
trigger5 = movecontact = 1
trigger6 = stateno = 450
trigger6 = movecontact = 1   
trigger7 = stateno = 410
trigger7 = movecontact = 1 

;--------------------
; Stand_Z
[State -1]
type = ChangeState
value = 250
triggerall = command = "z"
triggerall = command != "holddown"
trigger1 = statetype = s
trigger1 = ctrl = 1
trigger1 = P2Dist X >= 1
trigger2 = stateno = 200
trigger2 = movecontact = 1 
trigger3 = stateno = 210
trigger3 = movecontact = 1 
trigger4 = stateno = 230
trigger4 = movecontact = 1 

;------------------
; Stand_fwd_X
[State -1]
type = ChangeState
value = 235
triggerall = command = "fwd_x"
triggerall = command != "holddown"
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger1 = P2Dist X >= 1

;---------------------------------------------------------------------------
;Crouch_A
[State -1]
type = ChangeState
value = 400
triggerall = command = "a"
triggerall = command = "holddown"
trigger1 = statetype = C
trigger1 = ctrl = 1
trigger1 = P2Dist X >= 1

;---------------------------------------------------------------------------
;Crouch_B
[State -1]
type = ChangeState
value = 410
triggerall = command = "b"
triggerall = command = "holddown"
trigger1 = statetype = C
trigger1 = ctrl = 1
trigger1 = P2Dist X >= 1

;--------------------------------------------------------------------------
; Crouch_C
[state -1]
type = ChangeState
value = 420
triggerall = command = "c"
triggerall = command = "holddown"
trigger1 = statetype = c
trigger1 = ctrl = 1
trigger1 = P2Dist X >= 1

;--------------------------------------------------------------------------
; Crouch_X
[State -1]
type = ChangeState
value = 430
triggerall = command = "x"
triggerall = command = "holddown"
trigger1 = statetype = c
trigger1 = ctrl = 1
trigger1 = P2Dist X >= 1

;--------------------------------------------------------------------------
; Crouch_Y
[State -1]
type = ChangeState
value = 440
triggerall = command = "y"
tirggerall = command = holddown
trigger1 = statetype = c
trigger1 = ctrl = 1
trigger1 = P2Dist X >= 1
trigger2 = stateno = 410
trigger2 = movecontact = 1 

;---------------------------------------------------------------------------
; Crouch_Z
[State -1]
type = ChangeState
value = 450
triggerall = command = "z"
triggerall = command = "holddown"
trigger1 = statetype = c
trigger1 = ctrl = 1
trigger1 = P2Dist X >= 1

;---------------------------------------------------------------------------
;Jump_A
[State -1]
type = ChangeState
value = 600
trigger1 = command = "a"
trigger1 = statetype = A
trigger1 = ctrl = 1
trigger2 = stateno = 630
trigger2 = movecontact = 1 

;---------------------------------------------------------------------------
;Jump_B
[State -1]
type = ChangeState
value = 610
trigger1 = command = "b"
trigger1 = statetype = A
trigger1 = ctrl = 1
trigger2 = stateno = 600
trigger2 = movecontact = 1 
trigger3 = stateno = 630
trigger3 = movecontact = 1 
trigger4 = stateno = 640
trigger4 = movecontact = 1 

;----------------------------------------------------------------------------
; Jump_C
[State -1]
type = ChangeState
value = 620
trigger1 = command = "c"
trigger1 = statetype = A
trigger1 = ctrl = 1

;---------------------------------------------------------------------------
; Jump_X
[State -1]
type = ChangeState
value = 630
trigger1 = command = "x"
trigger1 = statetype = A
trigger1 = ctrl = 1

;--------------------------------------------------------------------------
; Jump_Y
[State -1]
type = ChangeState
value = 640
trigger1 = command = "y"
trigger1 = statetype = A
trigger1 = ctrl = 1

;------------------------------------------------------------------------
; Jump_Z
[State -1]
type = ChangeState
value = 650
trigger1 = command = "z"
trigger1 = statetype = A
trigger1 = ctrl = 1

;---------------------------------------------------------------------------
;Taunt Right 1
[State -1]
type = ChangeState
value = 194
triggerall = command = "start"
triggerall = ctrl = 1
triggerall = statetype = S
trigger1 = P2Dist X >= 1

;Taunt Right 2
[State -1]
type = ChangeState
value = 195
triggerall = command = "start"
triggerall = ctrl = 1
triggerall = statetype = S
trigger1 = P2Dist X >= 1

;Taunt Right 3
[State -1]
type = ChangeState
value = 196
triggerall = command = "start"
triggerall = ctrl = 1
triggerall = statetype = S
trigger1 = P2Dist X >= 1

;---------------------------------------------------------------------------
;Taunt Left 1
[State -1]
type = ChangeState
value = 197
triggerall = command = "start"
triggerall = ctrl = 1
triggerall = statetype = S
trigger1 = P2Dist X >= 1

;Taunt Left 2
[State -1]
type = ChangeState
value = 198
triggerall = command = "start"
triggerall = ctrl = 1
triggerall = statetype = S
trigger1 = P2Dist X >= 1

;Taunt Left 3
[State -1]
type = ChangeState
value = 199
triggerall = command = "start"
triggerall = ctrl = 1
triggerall = statetype = S
trigger1 = P2Dist X >= 1

;---------------------------------------------------------------------------

